﻿using Microsoft.Win32;
using System;
using System.IO;
using System.Windows;
using System.Windows.Input;
using System.Windows.Xps.Packaging;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// XPS 문서
        /// </summary>
        private XpsDocument xpsDocument;

        /// <summary>
        /// 파일 경로
        /// </summary>
        private string filePath;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 명령 실행시 처리하기 - Open_Executed(sender, e)

        /// <summary>
        /// 명령 실행시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Open_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();

            openFileDialog.InitialDirectory = Directory.GetCurrentDirectory();
            openFileDialog.Filter           = "XPS 문서 (*.xps)|*.xps";
            openFileDialog.FilterIndex      = 1;

            if(openFileDialog.ShowDialog().GetValueOrDefault())
            {
                if(this.xpsDocument != null)
                {
                    this.xpsDocument.Close();
                }

                try
                {
                    this.xpsDocument = new XpsDocument(openFileDialog.FileName, FileAccess.Read);
                }
                catch(UnauthorizedAccessException)
                {
                    MessageBox.Show(string.Format("다음 파일 경로에 접근할 수 없습니다 : {0}", openFileDialog.FileName));

                    return;
                }

                this.documentViewer.Document = this.xpsDocument.GetFixedDocumentSequence();

                this.filePath = openFileDialog.FileName;
            }
        }

        #endregion
        #region 종료 실행시 처리하기 - Close_Executed(sender, e)

        /// <summary>
        /// 종료 실행시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Close_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            Close();
        }

        #endregion
    }
}